/**
   Bojan Nikolic <b.nikolic@mrao.cam.ac.uk>, <bojan@bnikolic.co.uk>
   Initial version November 2010. 
   
   This file is part of LibAIR and is licensed under GNU Public
   License Version 2
   
   \file hdfutils.hpp

   Utilities for creating/writing/reading HDF5 files using the
   "C"-language interface
*/
#ifndef _LIBAIR_HD5_HDFUTILS_HPP__
#define _LIBAIR_HD5_HDFUTILS_HPP__

#include <vector>
#include <string>
#include <map>

#include <hdf5.h>
#include <hdf5_hl.h>

namespace hd5 {

  void write(hid_t fout,
	     const std::string &group,
	     const std::vector<double> &d);

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     const std::vector<double> &d);

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     size_t d3, 
	     const std::vector<double> &d);

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     const double *d);

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     size_t d3, 
	     const double *d);

  void write(hid_t fout,
	     const std::string &group,
	     const std::vector<int> &d);

  /** Write a map as a set of attributes to a group.

      \param prefix Each attribute starts with this string and is
      followed by the key of the map
   */
  void writeAtt(hid_t fout,
		const std::string &group,
		const std::string &prefix,
		const std::map<size_t, std::string> &m);

  

}

#endif
