%module pyair
%{
#include <numpy/arrayobject.h>

#include "mcpoint.hxx"

#include "../src/libair_main.hpp"
#include "../src/model_enums.hpp"
#include "../src/model_iface.hpp"
#include "../src/measure_iface.hpp"
#include "../src/dipmodel_iface.hpp"
#include "../src/dipmeasure_iface.hpp"

#include "../src/path_measure.hpp"
#include "../src/path_transfer.hpp"

#include "../src/lineshapes.hpp"
#include "../src/lineparams.hpp"
#include "../src/slice.hpp"
#include "../src/rtranfer.hpp"
#include "../src/columns_data.hpp"
#include "../src/columns.hpp"
#include "../src/radiometermeasure.hpp"
#include "../src/models_basic.hpp"
#include "../src/partitionsum.hpp"
#include "../src/partitionsum_testdata.hpp"
#include "../src/basicphys.hpp"
#include "../src/tbutils.hpp"
#include "../src/layers.hpp"
#include "../src/singlelayerwater.hpp"

#include "../src/model_water.hpp"
#include "../src/singlelayerwater.hpp"
#include "../src/cloudywater.hpp"
#include "../src/model_make.hpp"
#include "../src/dtdltools.hpp"

#include "../src/taumodel.hpp"
#include "../src/dispersion.hpp"

#include "../src/apps/almaresults.hpp"
#include "../src/apps/almaabs.hpp"
#include "../src/apps/arraydata.hpp"
#include "../src/apps/arraygains.hpp"
#include "../src/apps/dtdlcoeffs.hpp"
#include "../src/apps/almaopts.hpp"
#include "../src/apps/antennautils.hpp"


%}

%feature("autodoc", "1");

%ignore Water183Data;

%include "minimmodel.hxx"
%import "mcpoint.hxx"

%include "../src/libair_main.hpp"
%include "../src/model_enums.hpp"
%include "../src/model_iface.hpp"
%include "../src/measure_iface.hpp"
%include "../src/dipmodel_iface.hpp"
%include "../src/dipmeasure_iface.hpp"

%include "../src/path_measure.hpp"
%include "../src/path_transfer.hpp"

%include "../src/lineshapes.hpp"
%include "../src/lineparams.hpp"
%include "../src/slice.hpp"
%include "../src/rtranfer.hpp"
%include "../src/columns_data.hpp"
%include "../src/columns.hpp"
%include "../src/radiometermeasure.hpp"
%include "../src/singlelayerwater.hpp"
%include "../src/models_basic.hpp"
%include "../src/partitionsum.hpp"
%include "../src/basicphys.hpp"
%include "../src/tbutils.hpp"
%include "../src/model_water.hpp"
%include "../src/singlelayerwater.hpp"
%include "../src/cloudywater.hpp"
%include "../src/model_make.hpp"
%include "../src/dtdltools.hpp"

%include "../src/taumodel.hpp"
%include "../src/dispersion.hpp"

%include "std_vector.i"
%include "std_list.i"

namespace std {
  %template(ALMAAbsInpLBase) list<ALMAAbsInput>;
}

%include "../src/apps/antennautils.hpp"
%include "../src/apps/almaopts.hpp"
%include "../src/apps/almaresults.hpp"
%include "../src/apps/almaabs.hpp"
%include "../src/apps/arraydata.hpp"
%include "../src/apps/arraygains.hpp"
%include "../src/apps/dtdlcoeffs.hpp"


%init %{
  import_array();
%}

namespace LibAIR{
    %template(GrossLineD) GrossLine<double>;
    
    %template(WMSingleLayerWater) WaterModel<ISingleLayerWater>;

    %template(WMCloudy) WaterModel<ICloudyWater>;
}


namespace std {
   %template(doubleV) vector<double>;
}

namespace std {
	   %template(ListWP) list<Minim::WPPoint>; 
}

%inline %{
namespace LibAIR {

  PartitionTable * MkH2OPartTable(void)
  {
    return new   PartitionTable( getH2ORawTable() );
  }
}
%}

%extend LibAIR::WVRSkyDipLikely {
	
	Minim::MLikelihood *downcast(void) 
	{
	return self;
	}
}

%extend LibAIR::ALMAMeasure {
	
	Minim::MLikelihood *downcast(void) 
	{
	return self;
	}
}

%extend LibAIR::ArrayGains {
  
  PyObject *gp_path(void)
  {
    const size_t nd=LibAIR::ArrayGains::path_t::dimensionality;
    npy_intp dims[nd];
    for (size_t i=0; i<nd; ++i)
      dims[i]=self->g_path().shape()[i];
    return PyArray_SimpleNewFromData(nd, 
				     dims, 
				     NPY_FLOAT64, 
				     (void *)self->g_path().origin());
  }


 }

%extend LibAIR::InterpArrayData {

  PyObject *gp_time(void)
  {
    const size_t nd=1;
    npy_intp dims[nd];
    dims[0]=self->g_time().size();
    return PyArray_SimpleNewFromData(nd, 
				     dims, 
				     NPY_FLOAT64, 
				     (void *)&(self->g_time()[0]));
  }

  PyObject *gp_wvrdata(void)
  {
    const size_t nd=LibAIR::InterpArrayData::wvrdata_t::dimensionality;
    npy_intp dims[nd];
    for (size_t i=0; i<nd; ++i)
      dims[i]=self->g_wvrdata().shape()[i];
    return PyArray_SimpleNewFromData(nd, 
				     dims, 
				     NPY_FLOAT64, 
				     (void *)self->g_wvrdata().origin());
  }
 }
  
  
  
