/**
   \file t_iface.cpp

   Bojan Nikolic <b.nikolic@mrao.cam.ac.uk>, <bojan@bnikolic.co.uk>
   Testing of the top-level interface to libAIR
*/

#define BOOST_AUTO_TEST_MAIN

#include <cmath>
#include <iostream>

#include <boost/test/unit_test.hpp>
#include <boost/test/auto_unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <boost/assign/list_of.hpp>

#include <boost/shared_ptr.hpp>

#include "minim.hxx"
#include "minimmodel.hxx"
#include "lmmin.hxx"

#include "model_iface.hpp"
#include "dipmodel_iface.hpp"
#include "measure_iface.hpp"
#include "dipmeasure_iface.hpp"

#include "path_measure.hpp"
#include "path_transfer.hpp"
#include "radiometermeasure.hpp"
#include "model_make.hpp"


/// Set the n,T,P through Minim::ModelDesc interface
void setNTP(Minim::Model &model,
	    double n,
	    double T,
	    double P)
{
  Minim::ModelDesc md(model);
  md.getbyname("n")->setp(n);
  md.getbyname("T")->setp(T);
  md.getbyname("P")->setp(P);
}

BOOST_AUTO_TEST_CASE(Interfaces_Intentionaly_empty)
{
}

BOOST_AUTO_TEST_CASE(test_evalFn)
{
  LibAIR::ALMAWVRCharacter wvrchar;

  boost::scoped_ptr<LibAIR::WVRAtmoQuantModel> m(LibAIR::mkSingleLayerWater(wvrchar,
									    LibAIR::PartTable,
									    LibAIR::AirCont));
  setNTP(*m, 1, 270, 500);

  std::vector<double> Tb1; 
  m->eval(Tb1);
  
  boost::array<double, 4> Tb2=m->evalFn(1.0, "n");

  for(size_t i=0; i<4; ++i)
    BOOST_CHECK_EQUAL(Tb1[i], 
		      Tb2[i]);

  boost::array<double, 4> Tb3=m->evalFn(2.0, "n");

  setNTP(*m, 2, 270, 500);
  m->eval(Tb1);
  for(size_t i=0; i<4; ++i)
    BOOST_CHECK_EQUAL(Tb1[i], 
		      Tb3[i]);

  
  
}

